#line 5 "grecs-lex.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif	



#line 9 "grecs-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */

/* %if-c-only */
/* %if-not-reentrant */

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
    
/* %endif */

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* %if-c++-only */
/* %endif */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define grecs_grecs_const const
#else
#define grecs_grecs_const
#endif

/* %not-for-header */

/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (grecs_grecs__start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((grecs_grecs__start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE grecs_grecs_restart(grecs_grecs_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(grecs_grecs__state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct grecs_grecs__buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t grecs_grecs__size_t;
#endif

/* %if-not-reentrant */
extern grecs_grecs__size_t grecs_grecs_leng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *grecs_grecs_in, *grecs_grecs_out;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define grecs_grecs_less(n) \
	do \
		{ \
		/* Undo effects of setting up grecs_grecs_text. */ \
        int grecs_grecs_less_macro_arg = (n); \
        YY_LESS_LINENO(grecs_grecs_less_macro_arg);\
		*grecs_grecs__cp = (grecs_grecs__hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(grecs_grecs__c_buf_p) = grecs_grecs__cp = grecs_grecs__bp + grecs_grecs_less_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up grecs_grecs_text again */ \
		} \
	while ( 0 )

#define unput(c) grecs_grecs_unput( c, (grecs_grecs_text_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct grecs_grecs__buffer_state
	{
/* %if-c-only */
	FILE *grecs_grecs__input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *grecs_grecs__ch_buf;		/* input buffer */
	char *grecs_grecs__buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	grecs_grecs__size_t grecs_grecs__buf_size;

	/* Number of characters read into grecs_grecs__ch_buf, not including EOB
	 * characters.
	 */
	grecs_grecs__size_t grecs_grecs__n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int grecs_grecs__is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int grecs_grecs__is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int grecs_grecs__at_bol;

    int grecs_grecs__bs_lineno; /**< The line count. */
    int grecs_grecs__bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int grecs_grecs__fill_buffer;

	int grecs_grecs__buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via grecs_grecs_restart()), so that the user can continue scanning by
	 * just pointing grecs_grecs_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t grecs_grecs__buffer_stack_top = 0; /**< index of top of stack. */
static size_t grecs_grecs__buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * grecs_grecs__buffer_stack = 0; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (grecs_grecs__buffer_stack) \
                          ? (grecs_grecs__buffer_stack)[(grecs_grecs__buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (grecs_grecs__buffer_stack)[(grecs_grecs__buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */

/* grecs_grecs__hold_char holds the character lost when grecs_grecs_text is formed. */
static char grecs_grecs__hold_char;
static grecs_grecs__size_t grecs_grecs__n_chars;		/* number of characters read into grecs_grecs__ch_buf */
grecs_grecs__size_t grecs_grecs_leng;

/* Points to current character in buffer. */
static char *grecs_grecs__c_buf_p = (char *) 0;
static int grecs_grecs__init = 0;		/* whether we need to initialize */
static int grecs_grecs__start = 0;	/* start state number */

/* Flag which is used to allow grecs_grecs_wrap()'s to do buffer switches
 * instead of setting up a fresh grecs_grecs_in.  A bit of a hack ...
 */
static int grecs_grecs__did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void grecs_grecs_restart (FILE *input_file  );
void grecs_grecs__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE grecs_grecs__create_buffer (FILE *file,int size  );
void grecs_grecs__delete_buffer (YY_BUFFER_STATE b  );
void grecs_grecs__flush_buffer (YY_BUFFER_STATE b  );
void grecs_grecs_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void grecs_grecs_pop_buffer_state (void );

static void grecs_grecs_ensure_buffer_stack (void );
static void grecs_grecs__load_buffer_state (void );
static void grecs_grecs__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER grecs_grecs__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE grecs_grecs__scan_buffer (char *base,grecs_grecs__size_t size  );
YY_BUFFER_STATE grecs_grecs__scan_string (grecs_grecs_const char *grecs_grecs__str  );
YY_BUFFER_STATE grecs_grecs__scan_bytes (grecs_grecs_const char *bytes,grecs_grecs__size_t len  );

/* %endif */

void *grecs_grecs_alloc (grecs_grecs__size_t  );
void *grecs_grecs_realloc (void *,grecs_grecs__size_t  );
void grecs_grecs_free (void *  );

#define grecs_grecs__new_buffer grecs_grecs__create_buffer

#define grecs_grecs__set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        grecs_grecs_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grecs_grecs__create_buffer(grecs_grecs_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grecs_grecs__is_interactive = is_interactive; \
	}

#define grecs_grecs__set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        grecs_grecs_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grecs_grecs__create_buffer(grecs_grecs_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grecs_grecs__at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->grecs_grecs__at_bol)

/* %% [1.0] grecs_grecs_text/grecs_grecs_in/grecs_grecs_out/grecs_grecs__state_type/grecs_grecs_lineno etc. def's & init go here */
/* Begin user sect3 */

#define FLEX_DEBUG

typedef unsigned char YY_CHAR;

FILE *grecs_grecs_in = (FILE *) 0, *grecs_grecs_out = (FILE *) 0;

typedef int grecs_grecs__state_type;

extern int grecs_grecs_lineno;

int grecs_grecs_lineno = 1;

extern char *grecs_grecs_text;
#define grecs_grecs_text_ptr grecs_grecs_text

/* %if-c-only Standard (non-C++) definition */

static grecs_grecs__state_type grecs_grecs__get_previous_state (void );
static grecs_grecs__state_type grecs_grecs__try_NUL_trans (grecs_grecs__state_type current_state  );
static int grecs_grecs__get_next_buffer (void );
static void grecs_grecs__fatal_error (grecs_grecs_const char msg[]  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up grecs_grecs_text.
 */
#define YY_DO_BEFORE_ACTION \
	(grecs_grecs_text_ptr) = grecs_grecs__bp; \
/* %% [2.0] code to fiddle grecs_grecs_text and grecs_grecs_leng for grecs_grecs_more() goes here \ */\
	grecs_grecs_leng = (size_t) (grecs_grecs__cp - grecs_grecs__bp); \
	(grecs_grecs__hold_char) = *grecs_grecs__cp; \
	*grecs_grecs__cp = '\0'; \
/* %% [3.0] code to copy grecs_grecs_text_ptr to grecs_grecs_text[] goes here, if %array \ */\
	(grecs_grecs__c_buf_p) = grecs_grecs__cp;

/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 32
#define YY_END_OF_BUFFER 33
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct grecs_grecs__trans_info
	{
	flex_int32_t grecs_grecs__verify;
	flex_int32_t grecs_grecs__nxt;
	};
static grecs_grecs_const flex_int16_t grecs_grecs__accept[134] =
    {   0,
        0,    0,    2,    2,    0,    0,    0,    0,   33,   31,
       28,   29,   31,    9,   30,   13,   13,   31,   12,   28,
        9,    2,    4,    3,   32,   27,   32,   32,   32,   19,
       32,   28,    0,   14,    0,    9,    8,   13,    1,   11,
        0,   12,   28,    0,    9,    9,    9,    2,    3,    3,
        5,    0,   27,    0,    0,   19,    0,    0,    0,   18,
       16,   15,   13,   11,   10,   11,    0,    0,    0,    0,
       12,    0,    0,    0,    9,    9,    9,    0,   17,    0,
        0,    0,   22,    0,    0,    0,    0,    0,    0,    9,
        9,    0,    0,    0,    0,   20,    0,    0,    0,    9,

        9,    9,    0,    0,   25,    0,    0,    0,   21,    0,
        0,    0,    9,    6,    9,    9,    0,    0,   23,    0,
        0,    6,    0,    0,    9,    7,    0,   26,    0,   24,
        0,    7,    0
    } ;

static grecs_grecs_const flex_int32_t grecs_grecs__ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    7,    1,    1,    1,    1,    8,
        8,    9,    1,    8,   10,   11,   12,   13,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   11,    8,   15,
        1,    1,    1,   11,   16,   16,   16,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   16,   16,   16,
       11,   17,   11,    1,   16,    1,   16,   16,   16,   16,

       18,   16,   16,   16,   19,   16,   16,   20,   16,   21,
       16,   16,   16,   16,   16,   16,   16,   16,   16,   16,
       16,   16,    8,    1,    8,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static grecs_grecs_const flex_int32_t grecs_grecs__meta[22] =
    {   0,
        1,    2,    3,    1,    2,    4,    2,    1,    5,    6,
        7,    8,    9,    9,    1,   10,   11,   10,   10,   10,
       10
    } ;

static grecs_grecs_const flex_int16_t grecs_grecs__base[167] =
    {   0,
        0,   20,   20,   21,  249,   25,   28,   30,  215,  527,
       33,  527,   33,  211,  527,    0,   31,  198,   30,   49,
       55,    0,  527,   37,  209,  527,   41,   42,  527,  193,
        0,   60,   46,  527,  205,  201,  527,    0,  527,   75,
       91,   59,    0,  107,    0,  126,   95,    0,   90,   91,
      527,  200,  527,  101,   49,  527,    0,  185,  198,  527,
      527,  527,    0,  196,  527,    0,    0,  142,  158,    0,
      104,    0,  169,  178,  104,    0,  102,  103,  527,  187,
      187,  182,  527,  188,  193,  178,  120,    0,  167,  126,
      116,  127,  204,  180,  178,  527,  177,  173,  160,  130,

      132,  139,   69,    0,  527,  174,  164,  170,  527,  162,
      147,  149,  152,  527,  161,  159,  154,  153,  527,  146,
      163,  527,  169,  140,  134,  527,  108,  527,  104,  527,
       70,  527,  527,  216,  227,  238,  249,  260,  266,  271,
      281,  292,  303,  314,  325,  336,  347,  354,  361,  368,
      378,   57,  388,   16,  395,  405,  416,  427,  438,  449,
      460,  471,  482,  493,  504,  515
    } ;

static grecs_grecs_const flex_int16_t grecs_grecs__def[167] =
    {   0,
      133,    1,  134,  134,  135,  135,  136,  136,  133,  133,
      133,  133,  137,  138,  133,  139,  139,  133,  140,  133,
      138,  141,  133,  142,  143,  133,  143,  144,  133,  145,
      146,  133,  137,  133,  147,  138,  133,  148,  133,  133,
      149,  150,   20,  133,   21,   21,  138,  141,  142,  142,
      133,  143,  133,  143,  144,  133,  146,  145,  133,  133,
      133,  133,  148,  151,  133,   40,  152,  149,  153,  154,
      150,   44,  133,  133,   46,   46,  138,  143,  133,  155,
       68,  133,  133,  156,  153,  133,  133,   73,  133,  157,
      138,  143,  133,  155,  156,  133,  158,  159,  133,  157,

      160,  138,  143,   93,  133,  161,  133,  158,  133,  159,
      162,  133,  160,  133,  160,  163,  164,  161,  133,  165,
      162,  133,  162,  166,  163,  133,  164,  133,  165,  133,
      166,  133,    0,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133
    } ;

static grecs_grecs_const flex_int16_t grecs_grecs__nxt[549] =
    {   0,
       10,   11,   12,   11,   11,   13,   14,   15,   16,   16,
       16,   17,   16,   16,   18,   19,   10,   19,   19,   19,
       19,   20,   23,   23,   20,   69,   21,   26,   24,   24,
       29,   27,   29,   30,   32,   30,   32,   32,   34,   39,
       38,   38,   40,   53,   31,   50,   31,   56,   51,   35,
       43,   34,   32,   43,   56,   44,   45,   37,   57,   45,
       54,   32,   35,   32,   32,   57,   80,   63,   46,   63,
       63,   53,  132,  117,   47,   64,   64,   65,   64,   64,
       64,   64,   64,   66,   66,   66,   66,   66,   66,   64,
       66,   64,   66,   66,   66,   66,   67,   37,  133,   50,

       68,  133,   51,   53,   37,   53,  130,   70,   72,   90,
      128,   72,   63,   77,   63,   63,   36,   36,   37,   78,
       73,   87,   91,   92,   87,   98,   74,   75,   37,   53,
       75,  101,   37,  102,  114,  101,  126,  115,   76,   76,
      116,   37,  132,  116,  103,   36,   81,   67,  130,  122,
      124,  133,  123,  124,  114,  119,  128,  115,   70,   82,
       83,  126,   82,  114,   84,  122,  115,  111,  123,   86,
       87,  122,  109,   87,  123,  120,  119,  112,  111,  109,
       96,   88,   88,   82,   83,   93,   82,   99,   84,   97,
       96,  133,   93,   86,   82,   83,   89,   82,   65,   84,

       79,   59,   53,   37,   86,  104,  105,   62,  104,   59,
      106,   53,   41,   37,  133,  107,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   33,
       33,   26,   33,   33,   33,   33,   33,   33,   33,   33,
       36,   36,   36,   36,   36,   36,   36,   36,   36,   36,
       36,   38,   38,   38,   38,   38,   42,   42,   42,   42,
       42,   48,   48,  133,   48,  133,   48,   48,   48,   48,
       48,   48,   49,   49,  133,   49,   49,   49,   49,   49,

       49,   49,   49,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   55,   55,  133,   55,   55,   55,
       55,   55,   55,   55,   55,   58,   58,  133,  133,   58,
       58,   58,   58,   58,   58,   58,   60,   60,  133,   60,
       60,   60,   60,   60,   60,   60,   60,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   63,   63,
       63,   63,   63,   63,   69,  133,   69,  133,  133,  133,
       69,   69,   71,   71,   71,   71,   71,   71,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   85,
       85,  133,  133,   85,  133,   85,   85,   85,   94,  133,

       94,  133,  133,   94,   94,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,  100,  100,  100,  100,
      100,  100,  100,  100,  100,  100,  100,  108,  108,  108,
      108,  108,  108,  108,  108,  108,  108,  108,  110,  110,
      133,  110,  110,  110,  110,  110,  110,  110,  110,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
      118,  118,  118,  118,  118,  118,  118,  118,  118,  118,
      118,  121,  121,  121,  121,  121,  121,  121,  121,  121,
      121,  121,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  127,  127,  127,  127,  127,  127,  127,

      127,  127,  127,  127,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  131,  131,  131,  131,  131,
      131,  131,  131,  131,  131,  131,    9,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133
    } ;

static grecs_grecs_const flex_int16_t grecs_grecs__chk[549] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    3,    4,    2,  154,    2,    6,    3,    4,
        7,    6,    8,    7,   11,    8,   11,   11,   13,   17,
       19,   19,   17,   27,    7,   24,    8,   28,   24,   13,
       20,   33,   20,   20,   55,   20,   21,   21,   28,   21,
       27,   32,   33,   32,   32,   55,  152,   42,   21,   42,
       42,  103,  131,  103,   21,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   41,   47,   49,   50,

       41,   49,   50,   54,   77,   78,  129,   41,   44,   75,
      127,   44,   71,   47,   71,   71,   75,   75,   91,   54,
       44,   87,   77,   78,   87,   87,   44,   46,   90,   92,
       46,   90,  100,   91,  101,  100,  125,  101,   46,   46,
      102,  102,  124,  102,   92,   46,   68,   68,  120,  111,
      112,   68,  111,  112,  113,  118,  117,  113,   68,   69,
       69,  116,   69,  115,   69,  121,  115,  110,  121,   69,
       73,  123,  108,   73,  123,  107,  106,   99,   98,   97,
       95,   73,   73,   82,   82,   94,   82,   89,   82,   86,
       84,   81,   80,   82,   85,   85,   74,   85,   64,   85,

       59,   58,   52,   36,   85,   93,   93,   35,   93,   30,
       93,   25,   18,   14,    9,   93,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  137,
      137,    5,  137,  137,  137,  137,  137,  137,  137,  137,
      138,  138,  138,  138,  138,  138,  138,  138,  138,  138,
      138,  139,  139,  139,  139,  139,  140,  140,  140,  140,
      140,  141,  141,    0,  141,    0,  141,  141,  141,  141,
      141,  141,  142,  142,    0,  142,  142,  142,  142,  142,

      142,  142,  142,  143,  143,  143,  143,  143,  143,  143,
      143,  143,  143,  143,  144,  144,    0,  144,  144,  144,
      144,  144,  144,  144,  144,  145,  145,    0,    0,  145,
      145,  145,  145,  145,  145,  145,  146,  146,    0,  146,
      146,  146,  146,  146,  146,  146,  146,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  148,  148,
      148,  148,  148,  148,  149,    0,  149,    0,    0,    0,
      149,  149,  150,  150,  150,  150,  150,  150,  151,  151,
      151,  151,  151,  151,  151,  151,  151,  151,  151,  153,
      153,    0,    0,  153,    0,  153,  153,  153,  155,    0,

      155,    0,    0,  155,  155,  156,  156,  156,  156,  156,
      156,  156,  156,  156,  156,  156,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  159,  159,
        0,  159,  159,  159,  159,  159,  159,  159,  159,  160,
      160,  160,  160,  160,  160,  160,  160,  160,  160,  160,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  162,  162,  162,  162,  162,  162,  162,  162,  162,
      162,  162,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  164,  164,  164,  164,  164,  164,  164,

      164,  164,  164,  164,  165,  165,  165,  165,  165,  165,
      165,  165,  165,  165,  165,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  166,  166,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133
    } ;

static grecs_grecs__state_type grecs_grecs__last_accepting_state;
static char *grecs_grecs__last_accepting_cpos;

extern int grecs_grecs__flex_debug;
int grecs_grecs__flex_debug = 1;

static grecs_grecs_const flex_int16_t grecs_grecs__rule_linenum[32] =
    {   0,
       91,   92,   93,   94,   95,   97,  101,  106,  107,  108,
      109,  111,  113,  119,  124,  130,  135,  138,  140,  147,
      148,  149,  150,  151,  152,  156,  159,  180,  182,  183,
      184
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define grecs_grecs_more() grecs_grecs_more_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *grecs_grecs_text;
#line 1 "grecs-lex.l"
/* grecs - Gray's Extensible Configuration System       -*- c -*- */
#define YY_NO_INPUT 1

#line 10 "grecs-lex.l"
/* grecs - Gray's Extensible Configuration System
   Copyright (C) 2007-2016 Sergey Poznyakoff

   Grecs is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 3 of the License, or (at your
   option) any later version.

   Grecs is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with Grecs. If not, see <http://www.gnu.org/licenses/>. */

#include <grecs.h>
#include <grecs-gram.h>
#include <unistd.h>
#include <fcntl.h>
#include <ctype.h>
#include <stdlib.h>
#include <errno.h>
  
#include <wordsplit.h>

static char *multiline_delimiter;
static size_t multiline_delimiter_len;
static int multiline_unescape;         /* Unescape here-document contents */
static int (*char_to_strip)(char);    /* Strip matching characters of each
					  here-document line */

struct grecs_locus_point grecs_current_locus_point;   /* Input file location */
/* Line correction.  Equals to the number of #line directives inserted into
   the input by the preprocessor instance.  The external preprocessor, if
   any, counts these as input lines and therefore the line numbers in *its*
   #line directives are offset by the value of XLINES.
   
   Uff, running two preprocessors is confusing...
*/
static size_t xlines; 

static void multiline_begin(char *);
static void multiline_add(char *);
static char *multiline_strip_tabs(char *text);
static int ident(void);
static int isemptystr(int off);
static void qstring_locus_fixup(void);

#define qstring() \
	((grecs_parser_options & GRECS_OPTION_QUOTED_STRING_CONCAT)	\
	 ? QSTRING : STRING)

#undef YY_INPUT
#define YY_INPUT(buf,result,max_size)					\
	do {								\
		if (grecs_preprocessor)					\
			result = fread(buf, 1, max_size, grecs_grecs_in);		\
		else							\
			result = grecs_preproc_fill_buffer(buf, max_size); \
	} while(0)

#define YY_USER_ACTION do {						\
		if (YYSTATE == 0) {					\
			grecs_grecs_lloc.beg = grecs_current_locus_point;		\
			grecs_grecs_lloc.beg.col++;				\
		}							\
  		grecs_current_locus_point.col += grecs_grecs_leng;		\
 		grecs_grecs_lloc.end = grecs_current_locus_point;			\
   	} while (0);


#line 791 "grecs-lex.c"

#define INITIAL 0
#define COMMENT 1
#define ML 2
#define STR 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int grecs_grecs__init_globals (void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int grecs_grecs_lex_destroy (void );

int grecs_grecs_get_debug (void );

void grecs_grecs_set_debug (int debug_flag  );

YY_EXTRA_TYPE grecs_grecs_get_extra (void );

void grecs_grecs_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *grecs_grecs_get_in (void );

void grecs_grecs_set_in  (FILE * in_str  );

FILE *grecs_grecs_get_out (void );

void grecs_grecs_set_out  (FILE * out_str  );

grecs_grecs__size_t grecs_grecs_get_leng (void );

char *grecs_grecs_get_text (void );

int grecs_grecs_get_lineno (void );

void grecs_grecs_set_lineno (int line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int grecs_grecs_wrap (void );
#else
extern int grecs_grecs_wrap (void );
#endif
#endif

/* %not-for-header */

/* %ok-for-header */

/* %endif */

#ifndef grecs_grecs_text_ptr
static void grecs_grecs__flex_strncpy (char *,grecs_grecs_const char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int grecs_grecs__flex_strlen (grecs_grecs_const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

#ifdef __cplusplus
static int grecs_grecs_input (void );
#else
static int input (void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( grecs_grecs_text, grecs_grecs_leng, 1, grecs_grecs_out )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->grecs_grecs__is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( grecs_grecs_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( grecs_grecs_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, grecs_grecs_in))==0 && ferror(grecs_grecs_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(grecs_grecs_in); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "grecs_grecs_terminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef grecs_grecs_terminate
#define grecs_grecs_terminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) grecs_grecs__fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */

/* %ok-for-header */

/* %not-for-header */

/* %tables-grecs_grecs_dmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int grecs_grecs_lex (void);

#define YY_DECL int grecs_grecs_lex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after grecs_grecs_text and grecs_grecs_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	if ( grecs_grecs_leng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->grecs_grecs__at_bol = \
				(grecs_grecs_text[grecs_grecs_leng - 1] == '\n'); \
	YY_USER_ACTION

/* %not-for-header */

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register grecs_grecs__state_type grecs_grecs__current_state;
	register char *grecs_grecs__cp, *grecs_grecs__bp;
	register int grecs_grecs__act;
    
/* %% [7.0] user's declarations go here */
#line 89 "grecs-lex.l"

         /* C-style comments */
#line 1040 "grecs-lex.c"

	if ( !(grecs_grecs__init) )
		{
		(grecs_grecs__init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (grecs_grecs__start) )
			(grecs_grecs__start) = 1;	/* first start state */

		if ( ! grecs_grecs_in )
/* %if-c-only */
			grecs_grecs_in = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! grecs_grecs_out )
/* %if-c-only */
			grecs_grecs_out = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			grecs_grecs_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				grecs_grecs__create_buffer(grecs_grecs_in,YY_BUF_SIZE );
		}

		grecs_grecs__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] grecs_grecs_more()-related code goes here */
		grecs_grecs__cp = (grecs_grecs__c_buf_p);

		/* Support of grecs_grecs_text. */
		*grecs_grecs__cp = (grecs_grecs__hold_char);

		/* grecs_grecs__bp points to the position in grecs_grecs__ch_buf of the start of
		 * the current run.
		 */
		grecs_grecs__bp = grecs_grecs__cp;

/* %% [9.0] code to set up and find next match goes here */
		grecs_grecs__current_state = (grecs_grecs__start);
		grecs_grecs__current_state += YY_AT_BOL();
grecs_grecs__match:
		do
			{
			register YY_CHAR grecs_grecs__c = grecs_grecs__ec[YY_SC_TO_UI(*grecs_grecs__cp)];
			if ( grecs_grecs__accept[grecs_grecs__current_state] )
				{
				(grecs_grecs__last_accepting_state) = grecs_grecs__current_state;
				(grecs_grecs__last_accepting_cpos) = grecs_grecs__cp;
				}
			while ( grecs_grecs__chk[grecs_grecs__base[grecs_grecs__current_state] + grecs_grecs__c] != grecs_grecs__current_state )
				{
				grecs_grecs__current_state = (int) grecs_grecs__def[grecs_grecs__current_state];
				if ( grecs_grecs__current_state >= 134 )
					grecs_grecs__c = grecs_grecs__meta[(unsigned int) grecs_grecs__c];
				}
			grecs_grecs__current_state = grecs_grecs__nxt[grecs_grecs__base[grecs_grecs__current_state] + (unsigned int) grecs_grecs__c];
			++grecs_grecs__cp;
			}
		while ( grecs_grecs__base[grecs_grecs__current_state] != 527 );

grecs_grecs__find_action:
/* %% [10.0] code to find the action number goes here */
		grecs_grecs__act = grecs_grecs__accept[grecs_grecs__current_state];
		if ( grecs_grecs__act == 0 )
			{ /* have to back up */
			grecs_grecs__cp = (grecs_grecs__last_accepting_cpos);
			grecs_grecs__current_state = (grecs_grecs__last_accepting_state);
			grecs_grecs__act = grecs_grecs__accept[grecs_grecs__current_state];
			}

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for grecs_grecs_lineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( grecs_grecs__flex_debug )
			{
			if ( grecs_grecs__act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( grecs_grecs__act < 32 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)grecs_grecs__rule_linenum[grecs_grecs__act], grecs_grecs_text );
			else if ( grecs_grecs__act == 32 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         grecs_grecs_text );
			else if ( grecs_grecs__act == 33 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( grecs_grecs__act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*grecs_grecs__cp = (grecs_grecs__hold_char);
			grecs_grecs__cp = (grecs_grecs__last_accepting_cpos);
			grecs_grecs__current_state = (grecs_grecs__last_accepting_state);
			goto grecs_grecs__find_action;

case 1:
YY_RULE_SETUP
#line 91 "grecs-lex.l"
BEGIN(COMMENT);
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 92 "grecs-lex.l"
/* eat anything that's not a '*' */
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 93 "grecs-lex.l"
/* eat up '*'s not followed by '/'s */
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 94 "grecs-lex.l"
grecs_locus_point_advance_line(grecs_current_locus_point);
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 95 "grecs-lex.l"
BEGIN(INITIAL);
	YY_BREAK
/* Line directive */
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 97 "grecs-lex.l"
{ grecs_parse_line_directive_cpp(grecs_grecs_text,
						    &grecs_grecs_lloc,
						    &grecs_current_locus_point,
						    &xlines); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 101 "grecs-lex.l"
{ grecs_parse_line_directive(grecs_grecs_text,
							       &grecs_grecs_lloc,
							       &grecs_current_locus_point,
							       &xlines); }
	YY_BREAK
/* End-of-line comments */
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 106 "grecs-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 107 "grecs-lex.l"
/* end-of-file comment */;
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 108 "grecs-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 109 "grecs-lex.l"
/* end-of-file comment */;
	YY_BREAK
/* Identifiers */
case 12:
YY_RULE_SETUP
#line 111 "grecs-lex.l"
return ident();
	YY_BREAK
/* Strings */
case 13:
YY_RULE_SETUP
#line 113 "grecs-lex.l"
{
	                   grecs_line_begin();
	                   grecs_line_add(grecs_grecs_text, grecs_grecs_leng);
                           grecs_grecs_lval.string = grecs_line_finish();
                           return STRING; }
	YY_BREAK
/* Quoted strings */
case 14:
YY_RULE_SETUP
#line 119 "grecs-lex.l"
{ grecs_line_begin();
                        grecs_line_add(grecs_grecs_text + 1, grecs_grecs_leng - 2);
                        grecs_grecs_lval.string = grecs_line_finish();
                        qstring_locus_fixup();
                        return qstring(); }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 124 "grecs-lex.l"
{ BEGIN(STR);
                         grecs_line_begin();
		         grecs_line_acc_grow_unescape_last(grecs_grecs_text + 1,
                                                           grecs_grecs_leng - 1,
                                                           &grecs_grecs_lloc);
                         grecs_locus_point_advance_line(grecs_current_locus_point); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 130 "grecs-lex.l"
{ BEGIN(STR);
                         grecs_line_begin();
		         grecs_line_acc_grow_unescape_last(grecs_grecs_text + 1,
                                                           grecs_grecs_leng - 1, 
                                                           &grecs_grecs_lloc); }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 135 "grecs-lex.l"
{ grecs_line_acc_grow_unescape_last(grecs_grecs_text, grecs_grecs_leng, 
                                                          &grecs_grecs_lloc);
                        grecs_locus_point_advance_line(grecs_current_locus_point); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 138 "grecs-lex.l"
{ grecs_line_acc_grow_unescape_last(grecs_grecs_text, grecs_grecs_leng, 
                                                          &grecs_grecs_lloc); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 140 "grecs-lex.l"
{ BEGIN(INITIAL);
                        if (grecs_grecs_leng > 1) 
				grecs_line_add(grecs_grecs_text, grecs_grecs_leng - 1); 
                        grecs_grecs_lval.string = grecs_line_finish();
			qstring_locus_fixup();    
		        return qstring(); }
	YY_BREAK
/* Multiline strings */
case 20:
/* rule 20 can match eol */
#line 148 "grecs-lex.l"
case 21:
/* rule 21 can match eol */
#line 149 "grecs-lex.l"
case 22:
/* rule 22 can match eol */
#line 150 "grecs-lex.l"
case 23:
/* rule 23 can match eol */
#line 151 "grecs-lex.l"
case 24:
/* rule 24 can match eol */
#line 152 "grecs-lex.l"
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 152 "grecs-lex.l"
{
                BEGIN(ML);
		multiline_begin(grecs_grecs_text+2); }
	YY_BREAK
/* Ignore m4 line statements */
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 156 "grecs-lex.l"
{
	grecs_locus_point_advance_line(grecs_current_locus_point);
}
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 159 "grecs-lex.l"
{ char *p = multiline_strip_tabs(grecs_grecs_text);
	   
           if (!strncmp(p, multiline_delimiter, multiline_delimiter_len)
	       && isemptystr(p + multiline_delimiter_len - grecs_grecs_text)) {
		   grecs_free(multiline_delimiter);
		   multiline_delimiter = NULL;
		   BEGIN(INITIAL);
		   grecs_grecs_lval.string = grecs_line_finish();

		   /* Update end pos */
		   grecs_grecs_lloc.end.line--;
		   for (grecs_grecs_lloc.end.col = 0,
				p = grecs_grecs_lval.string + strlen(grecs_grecs_lval.string) - 1;
			p > grecs_grecs_lval.string && p[-1] != '\n';
			grecs_grecs_lloc.end.col++, p--);
		   if (grecs_grecs_lloc.end.col == 0)
			   grecs_grecs_lloc.end.col = 1;
		   return MSTRING;
	   }
           grecs_locus_point_advance_line(grecs_current_locus_point);
	   multiline_add(p); } 
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 180 "grecs-lex.l"
;
	YY_BREAK
/* Other tokens */
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 182 "grecs-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); } 
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 183 "grecs-lex.l"
return grecs_grecs_text[0];
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 184 "grecs-lex.l"
{ if (isascii(grecs_grecs_text[0]) && isprint(grecs_grecs_text[0]))
		grecs_error(&grecs_grecs_lloc, 0,
			     _("stray character %c"), grecs_grecs_text[0]);
           else
		grecs_error(&grecs_grecs_lloc, 0,
			     _("stray character \\%03o"),
			       (unsigned char) grecs_grecs_text[0]); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 191 "grecs-lex.l"
ECHO;
	YY_BREAK
#line 1385 "grecs-lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(COMMENT):
case YY_STATE_EOF(ML):
case YY_STATE_EOF(STR):
	grecs_grecs_terminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int grecs_grecs__amount_of_matched_text = (int) (grecs_grecs__cp - (grecs_grecs_text_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*grecs_grecs__cp = (grecs_grecs__hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed grecs_grecs_in at a new source and called
			 * grecs_grecs_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(grecs_grecs__n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_grecs__n_chars;
			YY_CURRENT_BUFFER_LVALUE->grecs_grecs__input_file = grecs_grecs_in;
			YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for grecs_grecs__c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since grecs_grecs__c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (grecs_grecs__c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf[(grecs_grecs__n_chars)] )
			{ /* This was really a NUL. */
			grecs_grecs__state_type grecs_grecs__next_state;

			(grecs_grecs__c_buf_p) = (grecs_grecs_text_ptr) + grecs_grecs__amount_of_matched_text;

			grecs_grecs__current_state = grecs_grecs__get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * grecs_grecs__get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			grecs_grecs__next_state = grecs_grecs__try_NUL_trans( grecs_grecs__current_state );

			grecs_grecs__bp = (grecs_grecs_text_ptr) + YY_MORE_ADJ;

			if ( grecs_grecs__next_state )
				{
				/* Consume the NUL. */
				grecs_grecs__cp = ++(grecs_grecs__c_buf_p);
				grecs_grecs__current_state = grecs_grecs__next_state;
				goto grecs_grecs__match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up grecs_grecs__cp goes here */
				grecs_grecs__cp = (grecs_grecs__c_buf_p);
				goto grecs_grecs__find_action;
				}
			}

		else switch ( grecs_grecs__get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(grecs_grecs__did_buffer_switch_on_eof) = 0;

				if ( grecs_grecs_wrap( ) )
					{
					/* Note: because we've taken care in
					 * grecs_grecs__get_next_buffer() to have set up
					 * grecs_grecs_text, we can now set up
					 * grecs_grecs__c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(grecs_grecs__c_buf_p) = (grecs_grecs_text_ptr) + YY_MORE_ADJ;

					grecs_grecs__act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (grecs_grecs__did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(grecs_grecs__c_buf_p) =
					(grecs_grecs_text_ptr) + grecs_grecs__amount_of_matched_text;

				grecs_grecs__current_state = grecs_grecs__get_previous_state(  );

				grecs_grecs__cp = (grecs_grecs__c_buf_p);
				grecs_grecs__bp = (grecs_grecs_text_ptr) + YY_MORE_ADJ;
				goto grecs_grecs__match;

			case EOB_ACT_LAST_MATCH:
				(grecs_grecs__c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf[(grecs_grecs__n_chars)];

				grecs_grecs__current_state = grecs_grecs__get_previous_state(  );

				grecs_grecs__cp = (grecs_grecs__c_buf_p);
				grecs_grecs__bp = (grecs_grecs_text_ptr) + YY_MORE_ADJ;
				goto grecs_grecs__find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of grecs_grecs_lex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

/* grecs_grecs__get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int grecs_grecs__get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf;
	register char *source = (grecs_grecs_text_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (grecs_grecs__c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf[(grecs_grecs__n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->grecs_grecs__fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (grecs_grecs__c_buf_p) - (grecs_grecs_text_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((grecs_grecs__c_buf_p) - (grecs_grecs_text_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->grecs_grecs__n_chars = (grecs_grecs__n_chars) = 0;

	else
		{
			grecs_grecs__size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int grecs_grecs__c_buf_p_offset =
				(int) ((grecs_grecs__c_buf_p) - b->grecs_grecs__ch_buf);

			if ( b->grecs_grecs__is_our_buffer )
				{
				grecs_grecs__size_t new_size = b->grecs_grecs__buf_size * 2;

				if ( new_size <= 0 )
					b->grecs_grecs__buf_size += b->grecs_grecs__buf_size / 8;
				else
					b->grecs_grecs__buf_size *= 2;

				b->grecs_grecs__ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					grecs_grecs_realloc((void *) b->grecs_grecs__ch_buf,b->grecs_grecs__buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->grecs_grecs__ch_buf = 0;

			if ( ! b->grecs_grecs__ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(grecs_grecs__c_buf_p) = &b->grecs_grecs__ch_buf[grecs_grecs__c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf[number_to_move]),
			(grecs_grecs__n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->grecs_grecs__n_chars = (grecs_grecs__n_chars);
		}

	if ( (grecs_grecs__n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			grecs_grecs_restart(grecs_grecs_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((grecs_grecs__size_t) ((grecs_grecs__n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		grecs_grecs__size_t new_size = (grecs_grecs__n_chars) + number_to_move + ((grecs_grecs__n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf = (char *) grecs_grecs_realloc((void *) YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_grecs__get_next_buffer()" );
	}

	(grecs_grecs__n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf[(grecs_grecs__n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf[(grecs_grecs__n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(grecs_grecs_text_ptr) = &YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf[0];

	return ret_val;
}

/* grecs_grecs__get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */

    static grecs_grecs__state_type grecs_grecs__get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	register grecs_grecs__state_type grecs_grecs__current_state;
	register char *grecs_grecs__cp;
    
/* %% [15.0] code to get the start state into grecs_grecs__current_state goes here */
	grecs_grecs__current_state = (grecs_grecs__start);
	grecs_grecs__current_state += YY_AT_BOL();

	for ( grecs_grecs__cp = (grecs_grecs_text_ptr) + YY_MORE_ADJ; grecs_grecs__cp < (grecs_grecs__c_buf_p); ++grecs_grecs__cp )
		{
/* %% [16.0] code to find the next state goes here */
		register YY_CHAR grecs_grecs__c = (*grecs_grecs__cp ? grecs_grecs__ec[YY_SC_TO_UI(*grecs_grecs__cp)] : 1);
		if ( grecs_grecs__accept[grecs_grecs__current_state] )
			{
			(grecs_grecs__last_accepting_state) = grecs_grecs__current_state;
			(grecs_grecs__last_accepting_cpos) = grecs_grecs__cp;
			}
		while ( grecs_grecs__chk[grecs_grecs__base[grecs_grecs__current_state] + grecs_grecs__c] != grecs_grecs__current_state )
			{
			grecs_grecs__current_state = (int) grecs_grecs__def[grecs_grecs__current_state];
			if ( grecs_grecs__current_state >= 134 )
				grecs_grecs__c = grecs_grecs__meta[(unsigned int) grecs_grecs__c];
			}
		grecs_grecs__current_state = grecs_grecs__nxt[grecs_grecs__base[grecs_grecs__current_state] + (unsigned int) grecs_grecs__c];
		}

	return grecs_grecs__current_state;
}

/* grecs_grecs__try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = grecs_grecs__try_NUL_trans( current_state );
 */
/* %if-c-only */
    static grecs_grecs__state_type grecs_grecs__try_NUL_trans  (grecs_grecs__state_type grecs_grecs__current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	register int grecs_grecs__is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	register char *grecs_grecs__cp = (grecs_grecs__c_buf_p);

	register YY_CHAR grecs_grecs__c = 1;
	if ( grecs_grecs__accept[grecs_grecs__current_state] )
		{
		(grecs_grecs__last_accepting_state) = grecs_grecs__current_state;
		(grecs_grecs__last_accepting_cpos) = grecs_grecs__cp;
		}
	while ( grecs_grecs__chk[grecs_grecs__base[grecs_grecs__current_state] + grecs_grecs__c] != grecs_grecs__current_state )
		{
		grecs_grecs__current_state = (int) grecs_grecs__def[grecs_grecs__current_state];
		if ( grecs_grecs__current_state >= 134 )
			grecs_grecs__c = grecs_grecs__meta[(unsigned int) grecs_grecs__c];
		}
	grecs_grecs__current_state = grecs_grecs__nxt[grecs_grecs__base[grecs_grecs__current_state] + (unsigned int) grecs_grecs__c];
	grecs_grecs__is_jam = (grecs_grecs__current_state == 133);

		return grecs_grecs__is_jam ? 0 : grecs_grecs__current_state;
}

/* %if-c-only */

/* %endif */

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int grecs_grecs_input (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(grecs_grecs__c_buf_p) = (grecs_grecs__hold_char);

	if ( *(grecs_grecs__c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* grecs_grecs__c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (grecs_grecs__c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->grecs_grecs__ch_buf[(grecs_grecs__n_chars)] )
			/* This was really a NUL. */
			*(grecs_grecs__c_buf_p) = '\0';

		else
			{ /* need more input */
			grecs_grecs__size_t offset = (grecs_grecs__c_buf_p) - (grecs_grecs_text_ptr);
			++(grecs_grecs__c_buf_p);

			switch ( grecs_grecs__get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because grecs_grecs__g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					grecs_grecs_restart(grecs_grecs_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( grecs_grecs_wrap( ) )
						return EOF;

					if ( ! (grecs_grecs__did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return grecs_grecs_input();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(grecs_grecs__c_buf_p) = (grecs_grecs_text_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (grecs_grecs__c_buf_p);	/* cast for 8-bit char's */
	*(grecs_grecs__c_buf_p) = '\0';	/* preserve grecs_grecs_text */
	(grecs_grecs__hold_char) = *++(grecs_grecs__c_buf_p);

/* %% [19.0] update BOL and grecs_grecs_lineno */
	YY_CURRENT_BUFFER_LVALUE->grecs_grecs__at_bol = (c == '\n');

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void grecs_grecs_restart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        grecs_grecs_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            grecs_grecs__create_buffer(grecs_grecs_in,YY_BUF_SIZE );
	}

	grecs_grecs__init_buffer(YY_CURRENT_BUFFER,input_file );
	grecs_grecs__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void grecs_grecs__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		grecs_grecs_pop_buffer_state();
	 *		grecs_grecs_push_buffer_state(new_buffer);
     */
	grecs_grecs_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grecs_grecs__c_buf_p) = (grecs_grecs__hold_char);
		YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buf_pos = (grecs_grecs__c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grecs_grecs__n_chars = (grecs_grecs__n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	grecs_grecs__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (grecs_grecs_wrap()) processing, but the only time this flag
	 * is looked at is after grecs_grecs_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(grecs_grecs__did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void grecs_grecs__load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(grecs_grecs__n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_grecs__n_chars;
	(grecs_grecs_text_ptr) = (grecs_grecs__c_buf_p) = YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buf_pos;
	grecs_grecs_in = YY_CURRENT_BUFFER_LVALUE->grecs_grecs__input_file;
	(grecs_grecs__hold_char) = *(grecs_grecs__c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE grecs_grecs__create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) grecs_grecs_alloc(sizeof( struct grecs_grecs__buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_grecs__create_buffer()" );

	b->grecs_grecs__buf_size = size;

	/* grecs_grecs__ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->grecs_grecs__ch_buf = (char *) grecs_grecs_alloc(b->grecs_grecs__buf_size + 2  );
	if ( ! b->grecs_grecs__ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_grecs__create_buffer()" );

	b->grecs_grecs__is_our_buffer = 1;

	grecs_grecs__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with grecs_grecs__create_buffer()
 * 
 */
/* %if-c-only */
    void grecs_grecs__delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->grecs_grecs__is_our_buffer )
		grecs_grecs_free((void *) b->grecs_grecs__ch_buf  );

	grecs_grecs_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a grecs_grecs_restart() or at EOF.
 */
/* %if-c-only */
    static void grecs_grecs__init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	grecs_grecs__flush_buffer(b );

	b->grecs_grecs__input_file = file;
	b->grecs_grecs__fill_buffer = 1;

    /* If b is the current buffer, then grecs_grecs__init_buffer was _probably_
     * called from grecs_grecs_restart() or through grecs_grecs__get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->grecs_grecs__bs_lineno = 1;
        b->grecs_grecs__bs_column = 0;
    }

/* %if-c-only */

        b->grecs_grecs__is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void grecs_grecs__flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->grecs_grecs__n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->grecs_grecs__ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->grecs_grecs__ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->grecs_grecs__buf_pos = &b->grecs_grecs__ch_buf[0];

	b->grecs_grecs__at_bol = 1;
	b->grecs_grecs__buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		grecs_grecs__load_buffer_state( );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void grecs_grecs_push_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	grecs_grecs_ensure_buffer_stack();

	/* This block is copied from grecs_grecs__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grecs_grecs__c_buf_p) = (grecs_grecs__hold_char);
		YY_CURRENT_BUFFER_LVALUE->grecs_grecs__buf_pos = (grecs_grecs__c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grecs_grecs__n_chars = (grecs_grecs__n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(grecs_grecs__buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from grecs_grecs__switch_to_buffer. */
	grecs_grecs__load_buffer_state( );
	(grecs_grecs__did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void grecs_grecs_pop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	grecs_grecs__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((grecs_grecs__buffer_stack_top) > 0)
		--(grecs_grecs__buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		grecs_grecs__load_buffer_state( );
		(grecs_grecs__did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void grecs_grecs_ensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	grecs_grecs__size_t num_to_alloc;
    
	if (!(grecs_grecs__buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(grecs_grecs__buffer_stack) = (struct grecs_grecs__buffer_state**)grecs_grecs_alloc
								(num_to_alloc * sizeof(struct grecs_grecs__buffer_state*)
								);
		if ( ! (grecs_grecs__buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_grecs_ensure_buffer_stack()" );
								  
		memset((grecs_grecs__buffer_stack), 0, num_to_alloc * sizeof(struct grecs_grecs__buffer_state*));
				
		(grecs_grecs__buffer_stack_max) = num_to_alloc;
		(grecs_grecs__buffer_stack_top) = 0;
		return;
	}

	if ((grecs_grecs__buffer_stack_top) >= ((grecs_grecs__buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (grecs_grecs__buffer_stack_max) + grow_size;
		(grecs_grecs__buffer_stack) = (struct grecs_grecs__buffer_state**)grecs_grecs_realloc
								((grecs_grecs__buffer_stack),
								num_to_alloc * sizeof(struct grecs_grecs__buffer_state*)
								);
		if ( ! (grecs_grecs__buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_grecs_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((grecs_grecs__buffer_stack) + (grecs_grecs__buffer_stack_max), 0, grow_size * sizeof(struct grecs_grecs__buffer_state*));
		(grecs_grecs__buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE grecs_grecs__scan_buffer  (char * base, grecs_grecs__size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) grecs_grecs_alloc(sizeof( struct grecs_grecs__buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_grecs__scan_buffer()" );

	b->grecs_grecs__buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->grecs_grecs__buf_pos = b->grecs_grecs__ch_buf = base;
	b->grecs_grecs__is_our_buffer = 0;
	b->grecs_grecs__input_file = 0;
	b->grecs_grecs__n_chars = b->grecs_grecs__buf_size;
	b->grecs_grecs__is_interactive = 0;
	b->grecs_grecs__at_bol = 1;
	b->grecs_grecs__fill_buffer = 0;
	b->grecs_grecs__buffer_status = YY_BUFFER_NEW;

	grecs_grecs__switch_to_buffer(b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to grecs_grecs_lex() will
 * scan from a @e copy of @a str.
 * @param grecs_grecs_str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       grecs_grecs__scan_bytes() instead.
 */
YY_BUFFER_STATE grecs_grecs__scan_string (grecs_grecs_const char * grecs_grecs_str )
{
    
	return grecs_grecs__scan_bytes(grecs_grecs_str,strlen(grecs_grecs_str) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to grecs_grecs_lex() will
 * scan from a @e copy of @a bytes.
 * @param grecs_grecs_bytes the byte buffer to scan
 * @param _grecs_grecs_bytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE grecs_grecs__scan_bytes  (grecs_grecs_const char * grecs_grecs_bytes, grecs_grecs__size_t  _grecs_grecs_bytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	grecs_grecs__size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _grecs_grecs_bytes_len + 2;
	buf = (char *) grecs_grecs_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_grecs__scan_bytes()" );

	for ( i = 0; i < _grecs_grecs_bytes_len; ++i )
		buf[i] = grecs_grecs_bytes[i];

	buf[_grecs_grecs_bytes_len] = buf[_grecs_grecs_bytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = grecs_grecs__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in grecs_grecs__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->grecs_grecs__is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void grecs_grecs__fatal_error (grecs_grecs_const char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine grecs_grecs_less() so it works in section 3 code. */

#undef grecs_grecs_less
#define grecs_grecs_less(n) \
	do \
		{ \
		/* Undo effects of setting up grecs_grecs_text. */ \
        int grecs_grecs_less_macro_arg = (n); \
        YY_LESS_LINENO(grecs_grecs_less_macro_arg);\
		grecs_grecs_text[grecs_grecs_leng] = (grecs_grecs__hold_char); \
		(grecs_grecs__c_buf_p) = grecs_grecs_text + grecs_grecs_less_macro_arg; \
		(grecs_grecs__hold_char) = *(grecs_grecs__c_buf_p); \
		*(grecs_grecs__c_buf_p) = '\0'; \
		grecs_grecs_leng = grecs_grecs_less_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int grecs_grecs_get_lineno  (void)
{
        
    return grecs_grecs_lineno;
}

/** Get the input stream.
 * 
 */
FILE *grecs_grecs_get_in  (void)
{
        return grecs_grecs_in;
}

/** Get the output stream.
 * 
 */
FILE *grecs_grecs_get_out  (void)
{
        return grecs_grecs_out;
}

/** Get the length of the current token.
 * 
 */
grecs_grecs__size_t grecs_grecs_get_leng  (void)
{
        return grecs_grecs_leng;
}

/** Get the current token.
 * 
 */

char *grecs_grecs_get_text  (void)
{
        return grecs_grecs_text;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param line_number
 * 
 */
void grecs_grecs_set_lineno (int  line_number )
{
    
    grecs_grecs_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see grecs_grecs__switch_to_buffer
 */
void grecs_grecs_set_in (FILE *  in_str )
{
        grecs_grecs_in = in_str ;
}

void grecs_grecs_set_out (FILE *  out_str )
{
        grecs_grecs_out = out_str ;
}

int grecs_grecs_get_debug  (void)
{
        return grecs_grecs__flex_debug;
}

void grecs_grecs_set_debug (int  bdebug )
{
        grecs_grecs__flex_debug = bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int grecs_grecs__init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from grecs_grecs_lex_destroy(), so don't allocate here.
     */

    (grecs_grecs__buffer_stack) = 0;
    (grecs_grecs__buffer_stack_top) = 0;
    (grecs_grecs__buffer_stack_max) = 0;
    (grecs_grecs__c_buf_p) = (char *) 0;
    (grecs_grecs__init) = 0;
    (grecs_grecs__start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    grecs_grecs_in = stdin;
    grecs_grecs_out = stdout;
#else
    grecs_grecs_in = (FILE *) 0;
    grecs_grecs_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * grecs_grecs_lex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* grecs_grecs_lex_destroy is for both reentrant and non-reentrant scanners. */
int grecs_grecs_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		grecs_grecs__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		grecs_grecs_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	grecs_grecs_free((grecs_grecs__buffer_stack) );
	(grecs_grecs__buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * grecs_grecs_lex() is called, initialization will occur. */
    grecs_grecs__init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef grecs_grecs_text_ptr
static void grecs_grecs__flex_strncpy (char* s1, grecs_grecs_const char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int grecs_grecs__flex_strlen (grecs_grecs_const char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *grecs_grecs_alloc (grecs_grecs__size_t  size )
{
	return (void *) malloc( size );
}

void *grecs_grecs_realloc  (void * ptr, grecs_grecs__size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void grecs_grecs_free (void * ptr )
{
	free( (char *) ptr );	/* see grecs_grecs_realloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-grecs_grecs_tables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "grecs_grecs_tables"
/* %endif */

/* %ok-for-header */

#line 191 "grecs-lex.l"



pid_t grecs_preproc_pid;

int
grecs_grecs_wrap()
{
	if (grecs_preprocessor) {
		grecs_preproc_extrn_shutdown(grecs_preproc_pid);
		fclose(grecs_grecs_in);
	} else
		grecs_preproc_done();
	grecs_current_locus_point.file = NULL;
	return 1;
}

int
grecs_lex_begin(const char *name, int trace)
{
	grecs_grecs__flex_debug = trace;

	grecs_line_acc_create();
	
	if (grecs_preprocessor) {
		int fd;
	
		fd = open(name, O_RDONLY);
		if (fd == -1) {
			grecs_error(NULL, errno, _("Cannot open `%s'"), name);
			return 1;
		}
		close(fd);

		grecs_grecs_in = grecs_preproc_extrn_start(name, &grecs_preproc_pid);
		if (!grecs_grecs_in) {
			grecs_error(NULL, errno,
				     _("Unable to start external preprocessor `%s'"),
				     grecs_preprocessor);
			return 1;
		}
	} else
		return grecs_preproc_init(name);

	return 0;
}

void
grecs_lex_end(int err)
{
	grecs_line_acc_free();
}

static int
isemptystr(int off)
{
	for (; grecs_grecs_text[off] && isspace(grecs_grecs_text[off]); off++)
		;
	if (grecs_grecs_text[off] == ';') {
		int i;
		for (i = off + 1; grecs_grecs_text[i]; i++) 
			if (!isspace(grecs_grecs_text[i]))
				return 0;
		grecs_grecs_less(off);
		return 1;
	}
	return grecs_grecs_text[off] == 0;
}

char *
multiline_strip_tabs(char *text)
{
	if (char_to_strip)
		for (; *text && char_to_strip(*text); text++)
			;
	return text;
}

static void
multiline_add(char *s)
{
	if (multiline_unescape) {
		for (; *s; s++)	{
			if (*s == '\\') {
				grecs_line_acc_grow_char_unescape(s[1]);
				++s;
			} else
				grecs_line_acc_grow_char(*s);
		}
	} else
		grecs_line_add(s, strlen(s));
}

static int
is_tab(char c)
{
	return c == '\t';
}
 
static int
is_ws(char c)
{
	return c == '\t' || c == ' ';
}

void
multiline_begin(char *p)
{
	if (*p == '-') {
		if (*++p == ' ') {
			char_to_strip = is_ws;
			p++;
		} else
			char_to_strip = is_tab;
	} else
		char_to_strip = NULL;
	if (*p == '\\') {
		p++;
		multiline_unescape = 0;
		multiline_delimiter_len = strcspn(p, " \t");
	} else if (*p == '"') {
		char *q;
 
		p++;
		multiline_unescape = 0;
		q = strchr(p, '"');
		multiline_delimiter_len = q - p;
	} else {
		multiline_delimiter_len = strcspn(p, " \t");
		multiline_unescape = 1;
	}

	/* Remove trailing newline */
	multiline_delimiter_len--;
	multiline_delimiter = grecs_malloc(multiline_delimiter_len + 1);
	memcpy(multiline_delimiter, p, multiline_delimiter_len);
	multiline_delimiter[multiline_delimiter_len] = 0;
	grecs_line_begin();

	/* Update locus */
	grecs_locus_point_advance_line(grecs_current_locus_point);
	grecs_grecs_lloc.beg = grecs_current_locus_point;
	grecs_grecs_lloc.beg.col++;
}

static int
ident()
{
	char *p;
	char *str;
	size_t len;
  
	for (p = grecs_grecs_text; *p && isspace(*p); p++)
		;

	len = strlen(p);
	str = grecs_malloc(len + 1);
	strcpy(str, p);
	grecs_grecs_lval.string = str;
	return IDENT;
}

static void
qstring_locus_fixup()
{
	if (grecs_parser_options & GRECS_OPTION_ADJUST_STRING_LOCATIONS) {
		grecs_grecs_lloc.beg.col++;
		grecs_grecs_lloc.end.col--;
	}
}

grecs_value_t *
grecs_value_ptr_from_static(grecs_value_t *input)
{
	grecs_value_t *ptr = grecs_malloc(sizeof(*ptr));
	*ptr = *input;
	return ptr;
}


static int
assign_locus(struct grecs_locus_point *ploc,
	     char *name, char *line, size_t *pxlines)
{
	char *p;
	
	if (name) {
		if (pxlines && (!ploc->file || strcmp(name, ploc->file)))
			*pxlines = 0;
		ploc->file = grecs_install_text(name);
	}
	ploc->line = strtoul(line, &p, 10) - (pxlines ? *pxlines : 0);
	ploc->col = 0;
	return *p != 0;
}

void
grecs_parse_line_directive(char *text, grecs_locus_t *ploc,
			   struct grecs_locus_point *ppoint, size_t *pxlines)
{
	int rc = 1;
	struct wordsplit ws;
	
	if (wordsplit(text, &ws, WRDSF_DEFFLAGS))
		grecs_error(ploc, 0, _("cannot parse #line line: %s"),
			    wordsplit_strerror(&ws));
	else {
		if (ws.ws_wordc == 2)
			rc = assign_locus(ppoint, NULL,
					   ws.ws_wordv[1], pxlines);
		else if (ws.ws_wordc == 3) 
			rc = assign_locus(ppoint, ws.ws_wordv[2],
					   ws.ws_wordv[1], pxlines);
		else if (ws.ws_wordc == 4) {
			rc = assign_locus(ppoint, ws.ws_wordv[2],
					   ws.ws_wordv[1], 0);
			if (pxlines && rc == 0) {
				char *p;
				unsigned long x = strtoul(ws.ws_wordv[3],
							   &p, 10);
				rc = *p != 0;
				if (rc == 0)
					*pxlines = x;
			}
		} else 
			grecs_error(ploc, 0, _("invalid #line statement"));
	
		if (rc) 
			grecs_error(ploc, 0, _("malformed #line statement"));
		wordsplit_free(&ws);
	}
}

void
grecs_parse_line_directive_cpp(char *text, grecs_locus_t *ploc,
			       struct grecs_locus_point *ppoint,
			       size_t *pxlines)
{
	struct wordsplit ws;
	
	if (wordsplit(text, &ws, WRDSF_DEFFLAGS)) {
		grecs_error(ploc, 0, _("cannot parse #line line: %s"),
			    wordsplit_strerror(&ws));
		return;
	} else if (ws.ws_wordc < 3)
		grecs_error(ploc, 0, _("invalid #line statement"));
	else {
		if (assign_locus(ppoint, ws.ws_wordv[2],
				 ws.ws_wordv[1], pxlines))
			grecs_error(ploc, 0, _("malformed #line statement"));
	}
	wordsplit_free(&ws);
}


